
///////////////////////////////////////////////////////////////////////////
//  Author: W.G.Gong
//  Email: gong@mppmu.mpg.de
//  Date:  Oct 25, 1996
///////////////////////////////////////////////////////////////////////////
#ifndef CHAMBER_H
#define CHAMBER_H

#include "constant.h"
class Inparam;

//
//  class chamber will define the geometries 
//
class Chamber
{
    public:
              Chamber(const Inparam& inp);
              Chamber(const fNumber rmin, const fNumber rmax, 
                      const fNumber phimin, const fNumber phimax,
                      const fNumber zmin, const fNumber length, 
                      const fNumber voltage);
              ~Chamber();
         void Initialize();	         // initialize chamber geometries
                                         // it should be rewriten later 
                                         // to parse gstar geometry file
         void Print() const;             // print out all the parameters 
                                         // for this chamber   
								
       // set methods:			
       void SetRMin(const fNumber min)              {r_min = min;}
       void SetRMax(const fNumber max)              {r_max = max;}
       void SetPhiMin(const fNumber min, int d_r);   
       void SetPhiMax(const fNumber max, int d_r);    
       void SetZMin(const fNumber min)              {z_min = min;}
       void SetZMax(const fNumber max); 
       void SetChamberLength(const fNumber length);
       void SetCathodeVoltage(const fNumber voltage); 
								
        // get methods:
        fNumber GetRAtReadout() const;
        fNumber GetRMin() const            {return r_min;  }
        fNumber GetRMax() const            {return r_max;  }
        fNumber GetPhiMin(const int d_r) const;  
        fNumber GetPhiMax(const int d_r) const; 
        fNumber GetZMin() const            {return z_min;  }
        fNumber GetZMax() const            {return z_max;  }
        fNumber GetChamberLength() const   {return cham_length; }
        fNumber GetCathodeVoltage() const  {return cath_voltage;  }
            int GetDriftDirection() const  {return drift_direction;  }
 
    private:
        // variable declarations
        fNumber r_min;                // inner radius of chamber in cm
        fNumber r_max;                // outer radius of chamber in cm
        fNumber phi_min;              // starting angle of one sector in rad
        fNumber phi_max;              // stopping angle of one sector in rad
        fNumber z_min;                // starting Z of chamber in cm
        fNumber z_max;                // starting Z of chamber in cm
        fNumber cham_length;          // set chamber length in cm
            int defined;

        fNumber cath_voltage;         // drift cathode voltage (volt)
                                      // < 0 drift from rmin to rmax
                                      // > 0 drift from rmax to rmin
            int drift_direction;      // = +1 drift from rmin to rmax
                                      // = -1 drift from rmax to rmin

};

#endif


  
