///////////////////////////////////////////////////////////////////////////
//  Author: W.G.Gong
//  Email: gong@mppmu.mpg.de
//  Date:  Oct 25, 1996
///////////////////////////////////////////////////////////////////////////
#ifndef CLUSTER_H
#define CLUSTER_H

#include "constant.h"

class Field;

//
//  class cluster will diffuse and drift a cluster of electrons 
//  generated by ionization
//
class Cluster
{
    public:

                Cluster(const fNumber el, const fNumber sig_rad, 
                        const fNumber sig_phi, const fNumber r, 
                        const fNumber ph, const fNumber time);		
                                // constructor
                ~Cluster();     // destructor

           void DriftDiffuse(const Field  *field);	
                                // drift&diffuse in radial/azimuthal dir.
            int IsDrifting(const Field* field);   
                                // check if electron is still drifting

           void Print() const;
        fNumber GetElectron() const   {return electron;}   
                                // get the number of electrons
        fNumber GetSigRad() const    {return sigma_rad;}
                                // get the radial width
        fNumber GetSigPhi() const    {return sigma_phi;}
                                // get the azimuthal width
        fNumber GetRad() const       {return rad;}
                                // get the radial position
        fNumber GetPhi(const int d_r) const
                   {return (d_r ? phi*DPI : phi);}   
                                // get the azimuthal position
        fNumber GetDriftTime() const {return drift_time;}
                                // get the accumulated drift time in usec

    private:
        fNumber electron;	// number of electrons in a cluster
        fNumber sigma_rad;	// sigma width in radial dir
        fNumber sigma_phi;	// sigma width in azimuthal dir
        fNumber rad;		// radial position in cm 
        fNumber phi;		// azimuthal position in deg
        fNumber drift_time;	// accumulated drift time in usec.

};

#endif


