///////////////////////////////////////////////////////////////////////////
//  Author: W.G.Gong
//  Email: gong@mppmu.mpg.de
//  Date:  Oct 25, 1996
///////////////////////////////////////////////////////////////////////////

#ifndef CONSTANT_H
#define CONSTANT_H

#include <math.h>                  // C lib
#include <stdlib.h>
#include <string.h>
#include <ctype.h>

#include <iostream.h>              // C++ lib
#include <fstream.h>

typedef double fNumber;            

#define DPI    180/M_PI            // radian to deg
#define PID    M_PI/180            // deg to radian
#define PI     M_PI
#define PI_2   2*M_PI
#define MAXCH  255
#define NGRID  1000                // No. of grid points for Field
#define NTIM   300                 // No. of time slices in SCA
#define MAXADC 256                 // ADC dynamic range: 8 bits
#define ADC_CONVERSION 1000        // use 1ADC=1000 electron charges
#define THRESHOLD  1000            // 1000 electrons
#define NSTEP   21

#ifndef INPUTS           // input parameter definitions:
#define INPUTS           // Update "iNputs" and "inparam.C" consistently !!
enum iNputs {                      
    Random_number_gen = 1,
    Chamber_r_min,
    Chamber_r_max,
    Chamber_phi_min,
    Chamber_phi_max,
    Chamber_z_min,
    Chamber_cham_length,
    Chamber_cath_voltage,
    Gas_file_gas,
    Gas_attenuation,
    Gas_gas_gain,
    Gas_avg_ion_pot,
    Point_file_point,
    Readout_number_plane,
    Readout_pad_pitch,
    Readout_pad_length,
    Readout_sigma_prf,
    Readout_shaper_time,
    Readout_slice,
    Readout_file_cluster,
    Readout_file_adc
};
#endif                   // end of define INPUTS

#ifndef MYLIBS           // define global functions
#define MYLIBS

extern  int Locate(const int npt, const fNumber* x, const fNumber xx);
extern  fNumber Interpolate(const int npt, const fNumber* x, 
                            const fNumber* y, const int ich, 
                            const fNumber xx);
extern  fNumber InterpValue(const int npt, const fNumber* x, 
                            const fNumber* y, const fNumber xx);

extern  fNumber InteGauss(const fNumber x1, const fNumber x2,
                          const fNumber x0, const fNumber sig);
                               // integrate a gaussian dist. given
                               // low/up limit x1/x2, centroid x0, sigma sig

extern  void    rmarin(int ij, int kl);
extern  fNumber ranmar();

#endif                   // end of define MYLIBS


#endif                   // end of define CONSTANT_H
