///////////////////////////////////////////////////////////////////////////
//  Author: W.G.Gong
//  Email: gong@mppmu.mpg.de
//  Date:  Oct 25, 1996
///////////////////////////////////////////////////////////////////////////
#ifndef FIELDS_H
#define FIELDS_H

#include "constant.h"
#include "gas.h"
#include "chamber.h"

class Inparam;

//
//  class field  will divide radius into grid points and 
//  define efield and gas parameters at grid points.
//
class Field: public Gas, public Chamber
{
    public:
                Field(Inparam& inp);
                Field(const fNumber rmin, const fNumber rmax, 
                      const fNumber phimin, const fNumber phimax,
                      const fNumber zmin, const fNumber length, 
                      const fNumber voltage, const fNumber attenu, 
                      const fNumber gain, const fNumber aip, 
                      const char* file_gas);
                ~Field();
           void DefineField();      // define the field at grid points
           void Output() const;     // write out the field value for checking
            int GetGridIndex(const fNumber r) const;      
                                    // find the index for radius r 
        fNumber GetVelAtReadout() const;

        fNumber GetDeltaR() const;
        fNumber GetEField(const int i) const   
                   {return grid_point[i].ef;}
        fNumber GetVelocityZ(const int i) const        
                   {return grid_point[i].vel_z;}
        fNumber GetDiffusionX(const int i) const       
                   {return grid_point[i].diff_x;}
        fNumber GetDiffusionY(const int i) const       
                   {return grid_point[i].diff_y;}
        fNumber GetDiffusionZ(const int i) const       
                   {return grid_point[i].diff_z;}
        fNumber GetLorentzAngle(const int i) const     
                   {return grid_point[i].lorentz;}
        fNumber GetDlnvDr(const int i) const           
                   {return grid_point[i].dlnv_dr;}

    private:
        // variable declarations
        fNumber del_r;             // radial grid size

         struct grid_data {
                    fNumber rhit;       
                            // hit radius in cm
                    fNumber ef;         
                            // Efield in V/cm
                    fNumber vel_z;	   
                            // long.  drift speed in cm/usec
                    fNumber diff_z;     
                            // long. diffusion coeff. in um/sqrt(cm)
                    fNumber diff_x;     
                            // trans. diffusion coef. in um/sqrt(cm)
                    fNumber diff_y;     
                            // trans. diffusion coef. in um/sqrt(cm)
                    fNumber lorentz;    
                            // Lorentz angle in rad
                    fNumber dlnv_dr;    
                            // drift velocity gradient
                };
      grid_data grid_point[NGRID];

        fNumber RField(const fNumber r); // radial efield at r          

};

#endif

