///////////////////////////////////////////////////////////////////////////
//  Author: W.G.Gong
//  Email: gong@mppmu.mpg.de
//  Date:  Oct 25, 1996
///////////////////////////////////////////////////////////////////////////

#ifndef GAS_H
#define GAS_H

#include "constant.h"

class Inparam;

//
//  class gas will read in gas parameters from a magboltz calculation
// then interpolate the values at new electrical field grid points
//
class Gas
{
    public:
             Gas(Inparam& inp);
             Gas(const fNumber attenu, const fNumber gain, 
                 const fNumber avg_ion_pot, const char* file_gas);
             ~Gas();

        void ReadGas(const char* file_gas);	
                                    // read in gas parameters from a file
        void Print() const; 
        void Initialize();
        void SetAttenuation(const fNumber attenu)  {attenuation = attenu; }    
        void SetGasGain(const fNumber gain)        {gas_gain = gain; }
        void SetAvgIonPot(const fNumber aip)       {avg_ion_pot = aip; }

         int GetNGas() const              {return ngas; }
     fNumber GetAttenuation() const       {return attenuation; }
     fNumber GetGasGain() const           {return gas_gain;}
     fNumber GetAvgIonPot() const         {return avg_ion_pot; }

     fNumber GetInEfield(const int i) const
                {return gas_point[i].in_efield;}
     fNumber GetInVelocityZ(const int i) const
                {return gas_point[i].in_velocity_z;}
     fNumber GetInDiffusionZ(const int i) const
                {return gas_point[i].in_diffusion_z;}
     fNumber GetInDiffusionX(const int i) const
                {return gas_point[i].in_diffusion_x;}
     fNumber GetInDiffusionY(const int i) const
                {return gas_point[i].in_diffusion_y;}
     fNumber GetInAngleLorentz(const int i) const
                {return gas_point[i].in_angle_lorentz;}

    private:

       //  initial gas parameters from magboltz program
        struct gas_data {
                  fNumber in_efield;
                           // Efield in V/cm
                  fNumber in_velocity_z;	 
                           // long. drift speed in cm/micro-sec
                  fNumber in_diffusion_z;   	
                           // long. diffusion coeff. in micron/sqrt(cm)
                  fNumber in_diffusion_x;   	
                           // trans. diffusion coeff. in micron/sqrt(cm)
                  fNumber in_diffusion_y;   	
                           // trans. diffusion coeff. in micron/sqrt(cm)
                  fNumber in_angle_lorentz; 	
                           // Lorentz angle in radian
              };
     gas_data* gas_point; // pointer to gas_data

           int ngas; 
       fNumber attenuation;    // electron attenuation coeff [1/cm]
       fNumber gas_gain;       // gas gain factor
       fNumber avg_ion_pot;    // average ionization potential of this gas in eV
};

#endif

