///////////////////////////////////////////////////////////////////////////
//  Author: W.G.Gong
//  Email: gong@mppmu.mpg.de
//  Date:  Oct 25, 1996
///////////////////////////////////////////////////////////////////////////

#include "constant.h"
#include "inparam.h"
#include "gas.h"

Gas::Gas(Inparam& inp)
{
    SetAttenuation( inp.GetInParam(Gas_attenuation) );
    SetGasGain( inp.GetInParam(Gas_gas_gain) );
    SetAvgIonPot( inp.GetInParam(Gas_avg_ion_pot) );
    ReadGas( inp.GetFileName(Gas_file_gas) );
}

Gas::Gas(const fNumber attenu, const fNumber gain,
         const fNumber aip, const char* file_gas)
{
    SetAttenuation(attenu); 
    SetGasGain(gain);
    SetAvgIonPot(aip);
    ReadGas(file_gas);
}

Gas::~Gas() { }

void Gas::ReadGas(const char* file_gas)
{
    ifstream fin(file_gas);
    ofstream fout("/tmp/gas.tmp");

    // create a tmp file to get rid of # comments
    int counter = 0;
    char ch;
    while (fin.get(ch)) {
        if (ch == '#') {
            do {
               fin.get(ch);
            }
            while (ch != '\n');
            continue;
        }
        else {
            fout.put(ch);
            if(ch == '\n') counter++;
        }
    }

    fin.close();
    fout.close();


    ngas = counter;
    cout << "Number of gas parameter points = " << ngas << endl;

    gas_point  = new gas_data[ngas]; 

    // read in the tmp file with data only
    ifstream ifs("/tmp/gas.tmp");

    char space[] = "  ";
    fNumber f[11];
    for (counter=0; counter<ngas; ++counter) {
        ifs >>f[0]>>f[1]>>f[2]>>f[3]>>f[4]>>f[5]
            >>f[6]>>f[7]>>f[8]>>f[9]>>f[10];
 
        //fill in the parameter array
        gas_point[counter].in_efield        = f[0];
        gas_point[counter].in_velocity_z    = f[1];
        gas_point[counter].in_diffusion_z   = f[2];
        gas_point[counter].in_diffusion_x   = f[3];
        gas_point[counter].in_diffusion_y   = f[4];
        gas_point[counter].in_angle_lorentz = f[5]*PID ;

        //cout <<f[0]<<space<<f[1]<<space<<f[2]<<space<<f[3]<<space
        //     <<f[4]<<space<<f[5]<<endl;
    }

}

void Gas::Print() const 
{
    cout << " Gas gain = "
         << GetGasGain()  << endl;     
    cout << " Gas attenuation = "
         << GetAttenuation() << "[cm^-1]" << endl;
    cout << " Average Ionization Potential " 
         << GetAvgIonPot() << " [eV] " << endl;
    cout << " Number of gas parameter = "
         << GetNGas() << endl;
}


void Gas::Initialize()
{
    SetAttenuation(0.0);   // no attenuation 
    SetGasGain(1000.);     // gas gain of 1000
    SetAvgIonPot(26.);     // 26eV
    ReadGas("gas.dat");
}


