///////////////////////////////////////////////////////////////////////////
//  Author: W.G.Gong
//  Email: gong@mppmu.mpg.de
//  Date:  Oct 25, 1996
///////////////////////////////////////////////////////////////////////////

#include "constant.h"
#include "inparam.h"

//////////////////////////////
// initialize inpair[]
//////////////////////////////
struct dict_pair{
           char   dict_string[MAXCH];
           iNputs found_input;
       }; 

dict_pair inpair[] = {
            "Random.number_gen",     Random_number_gen,
            "Chamber.r_min",         Chamber_r_min,
            "Chamber.r_max",         Chamber_r_max,
            "Chamber.phi_min",       Chamber_phi_min,
            "Chamber.phi_max",       Chamber_phi_max,
            "Chamber.z_min",         Chamber_z_min,
            "Chamber.cham_length",   Chamber_cham_length,
            "Chamber.cath_voltage",  Chamber_cath_voltage,
            "Gas.file_gas",          Gas_file_gas,
            "Gas.attenuation",       Gas_attenuation,
            "Gas.gas_gain",          Gas_gas_gain,
            "Gas.avg_ion_pot",       Gas_avg_ion_pot,
            "Point.file_point",      Point_file_point,
            "Readout.number_plane",  Readout_number_plane,
            "Readout.pad_pitch",     Readout_pad_pitch,
            "Readout.pad_length",    Readout_pad_length,
            "Readout.sigma_prf",     Readout_sigma_prf,
            "Readout.shaper_time",   Readout_shaper_time,
            "Readout.slice",         Readout_slice,
            "Readout.file_cluster",  Readout_file_cluster,
            "Readout.file_adc",      Readout_file_adc,
            "",                      (enum iNputs)0     // terminator
          };

Inparam::Inparam(const char* file_config, const int DEBUG)
{
    ReadConfig( file_config, DEBUG) ;
}

Inparam::~Inparam() { }

int Inparam::LookupDictionary(const char in_string[]) const 
{
    dict_pair *pointer = &inpair[0];
    if (in_string[0] == 0) return 0;       // nothing to lookup
    
    do { if (strcmp(in_string, pointer->dict_string) == 0)
             return pointer->found_input;
        ++pointer;                         // next input on list
    } while (pointer->found_input);        // end of list

    cout << "Input " << in_string << " unknown!" << endl;
    return 0;                              // not found on list
}

int Inparam::SizeOfDictionary() const 
{
    dict_pair *pointer = &inpair[0];
    int size = 0;
    while (pointer->found_input) {
        ++size;
        ++pointer;                         // next input on list
    }
    return size;
}

void Inparam::ReadConfig( const char* file_config,  const int DEBUG)
{
    ifstream fin(file_config);       // open the config file to read
 
    int     i;
    int     MISSING = 0;             // set if missing input parameter
 
    char    EQUAL   = '=';
    char    sign;
 
    char    varnam[MAXCH];
    char    vararg[MAXCH];
 
    int  len  = SizeOfDictionary();
    if (DEBUG) cout << " number of words = " << len << endl;
 
    inp_arr = new fNumber[len+1];               
    for(i=0; i<(len+1); ++i)  inp_arr[i] = (fNumber) IS_MISS;
 
    char  c ;
    while (fin.get(c)) {
        if ( isspace(c) ) {
            continue;
        }
        else if ( c != '(' ) {
            do {
                fin.get(c); 
            } while ( c != '\n' );
            continue;
        } 
        else {
            fin >> varnam >> sign >> vararg; 
            if ( sign == EQUAL ) {
                if (DEBUG) 
                    cout << " matched: " 
                         << varnam << " ==== " << vararg << endl;
            }
            else {
                cerr << " error in reading config. file " << endl;
            }
           
            i = LookupDictionary(varnam);

            if (!i) {
                cerr << " parameter " << varnam << " is undefined " << endl;
                cerr << " check your spelling or dictionary inpair[]" << endl;
            }

            if (DEBUG) {
                cout << "i=" << i << endl;
                cout << vararg << "=" << atof(vararg) << endl;
            }
 
            if(isdigit(vararg[0]) || 
               vararg[0] == '-'   || vararg[0] == '+'  ) {
                inp_arr[i] = (fNumber) atof(vararg);
            }
            else if (i == Gas_file_gas) {
                strcpy(file_gas, vararg);
                inp_arr[i] = (fNumber) IS_FILE;
            }
            else if (i == Point_file_point) {
                strcpy(file_point, vararg);
                inp_arr[i] = (fNumber) IS_FILE;
            }
            else if (i == Readout_file_cluster) {
                strcpy(file_cluster, vararg);
                inp_arr[i] = (fNumber) IS_FILE;
            }
            else if (i == Readout_file_adc) {
                strcpy(file_adc, vararg);
                inp_arr[i] = (fNumber) IS_FILE;
            }
        }
    }
    fin.close();
 
    for(int j=1; j < (len+1); ++j) {
        if ( inp_arr[j] == (fNumber) IS_MISS ) {
            MISSING = 1;
            cerr << inpair[j-1].dict_string << " is missing " << endl;
        }
    }
    if (MISSING) {
        cerr << "input parameter incomplete, check config file" << endl;
        exit(1);
    }
}

char* Inparam::GetFileName(const iNputs i) 
{
    if ( i == Gas_file_gas ) {
        strcpy(file_name, file_gas);
    }
    else if ( i == Point_file_point ) {
        strcpy(file_name, file_point);
    }
    else if ( i == Readout_file_adc ) {
        strcpy(file_name, file_adc );
    }
    else if ( i == Readout_file_cluster) {
        strcpy(file_name, file_cluster);
    }
    else {
        strcpy(file_name, "bad file");
    }
    return file_name;
}


void Inparam::Print() const 
{
    int  len  = SizeOfDictionary();

    for(int i=1; i < (len+1); ++i) {
        if ( inp_arr[i] == (fNumber) IS_FILE ) {
          if ( i == Gas_file_gas ) 
            cout << inpair[i-1].dict_string << " = " << file_gas << endl;
          if ( i == Point_file_point ) 
            cout << inpair[i-1].dict_string << " = " << file_point << endl;
          if ( i == Readout_file_adc ) 
            cout << inpair[i-1].dict_string << " = " << file_adc << endl;
          if ( i == Readout_file_cluster ) 
            cout << inpair[i-1].dict_string << " = " << file_cluster << endl;
        }
        else {
            cout << inpair[i-1].dict_string << " = " << inp_arr[i] << endl;
        }
    }
}
