///////////////////////////////////////////////////////////////////////////
//  Author: W.G.Gong
//  Email: gong@mppmu.mpg.de
//  Date:  Oct 25, 1996
///////////////////////////////////////////////////////////////////////////

#include "constant.h"
#include "inparam.h"
#include "point.h"

Point::Point(Inparam& inp, const int DEBUG=0)
{
    ReadPoint(inp,DEBUG);
}

Point::~Point()  { }

void Point::ReadPoint(Inparam& inp, const int DEBUG=0)
{
    char file_point[MAXCH];
    strcpy(file_point, inp.GetFileName(Point_file_point));

    ifstream fin(file_point);
    ofstream fout("/tmp/point.tmp");

    // create a tmp file to get rid of # comments
    int counter = 0;
    char ch;
    while (fin.get(ch)) {
        if (ch == '#') {
            do {
               fin.get(ch);
            }
            while (ch != '\n');
            continue;
        }
        else {
            fout.put(ch);
            if(ch=='\n')counter++ ;
        }
    }

    fin.close();
    fout.close();

    cout << "Number of hit points = " << counter << endl;
    number_hits = counter;

    hitpoint = new hits[number_hits];

    // read in the tmp file with data only
    ifstream ifs("/tmp/point.tmp");
    ofstream ofs("/tmp/point.tmp1");

    fNumber f[15];
    fNumber r_tmp;
    fNumber phi_tmp;
    fNumber r_min    = inp.GetInParam(Chamber_r_min);
    fNumber r_max    = inp.GetInParam(Chamber_r_max);
    fNumber phi_min  = inp.GetInParam(Chamber_phi_min);
    fNumber phi_max  = inp.GetInParam(Chamber_phi_max);

    counter = 0;
    for (int i=0; i<number_hits; ++i) {
        ifs >>f[0]>>f[1]>>f[2]>>f[3]>>f[4]>>f[5]>>f[6]>>f[7]
            >>f[8]>>f[9]>>f[10]>>f[11]>>f[12]>>f[13]>>f[14];

        //fill in the array

        // calculate the polar coordinates
        r_tmp  =  sqrt(f[0]*f[0] + f[1]*f[1]);
        if(r_tmp < r_min || r_tmp > r_max) continue ;

        if (f[0] > 0.0) {
            if (f[1] >= 0.0) 
                phi_tmp = atan(f[1]/f[0]);
            else   
                phi_tmp = 2*PI + atan(f[1]/f[0]);
        }
        else if (f[0] < 0.0) {
                phi_tmp = PI + atan(f[1]/f[0]);
        }
        else {
            if (f[1] >= 0.0) 
                phi_tmp = 0.5*PI;
            else   
                phi_tmp = 1.5*PI ;
        }
        if(phi_tmp < phi_min || phi_tmp > phi_max) continue ;

        // old
        hitpoint[counter].x            = f[0];
        hitpoint[counter].y            = f[1];
        hitpoint[counter].z            = f[2];
        hitpoint[counter].de           = f[3];
        hitpoint[counter].row_id       = f[6];
        hitpoint[counter].track_id     = f[14];

        // new
        hitpoint[counter].r            = r_tmp;
        hitpoint[counter].phi          = phi_tmp;
        hitpoint[counter].dip_angle    = (f[4]*PID);
        hitpoint[counter].cross_angle  = (f[5]*PID);

        hitpoint[counter].dx           = 0.0;
        hitpoint[counter].dy           = 0.0;
        hitpoint[counter].dz           = 0.0;

        if (DEBUG) {
            ofs << hitpoint[counter].r << "  " 
                << hitpoint[counter].phi << "  "
                << hitpoint[counter].x << "  "
                << hitpoint[counter].y << "  "
                << hitpoint[counter].z << "  "
                << hitpoint[counter].de << "  " 
                << hitpoint[counter].dip_angle << "  "
                << hitpoint[counter].cross_angle << "  " 
                << hitpoint[counter].row_id << "  "
                << hitpoint[counter].track_id << "  "
                << endl;
        }

        ++counter;
    }

    ifs.close();
    ofs.close();

    cout << "Number of hit points accepted = " << counter << endl;
    number_hits = counter;

}


void Point::OutputCluster(const char* file_cluster)
{
    char space = ' ';
    ofstream fout(file_cluster);

    for( int i=0; i < GetNumberPoint(); ++i ) {

        fout << hitpoint[i].x << space
             << hitpoint[i].y << space
             << hitpoint[i].z << space
             << hitpoint[i].dx << space
             << hitpoint[i].dy << space
             << hitpoint[i].dz << space
             << hitpoint[i].de << space
             << hitpoint[i].row_id << space
             << hitpoint[i].track_id << space
             << endl;

    }

    fout.close();
}

